@@ -3,7 +3,7 @@ import logging
 import markdown
 import re
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 MACRO_RE = r'\[\[(?P<macro>(?P<name>[A-Za-z0-9_^(]+)\((?P<args>.*)\))\]\]'
 
@@ -51,8 +51,7 @@ class MacroExtension(markdown.Extension):
         self.config = {'macros': []}
         
         for conf in config:
-            if conf[0] == "macros":
-                self.config['macros'].extend(conf[1])
+            self.config[conf[0]] = conf[1]
 
     def extendMarkdown(self, md, md_globals):
         macroPattern = MacroPattern(MACRO_RE, self.config)
